@@ -14,6 +14,7 @@ from webbrowser import open_new_tab
 from PIL import ImageTk, Image
 from pynmeagps import version as PNVERSION
 from pyubx2 import version as PUVERSION
+from pyrtcm import version as RTVERSION
 from pygpsclient.helpers import check_for_update
 from pygpsclient.globals import ICON_APP, GITHUB_URL, PYPI_URL
 from pygpsclient.strings import ABOUTTXT, COPYRIGHTTXT, DLGABOUT
@@ -45,7 +46,6 @@ class AboutDialog:
         self._body()
         self._do_layout()
         self._attach_events()
-        self._check_for_update()
 
     def _body(self):
         """
@@ -56,7 +56,7 @@ class AboutDialog:
         self._lbl_title.config(font=self.__app.font_md2)
         self._lbl_icon = Label(self._dialog, image=self._img_icon)
         self._lbl_desc = Label(
-            self._dialog, text=ABOUTTXT, wraplength=250, font=self.__app.font_sm
+            self._dialog, text=ABOUTTXT, wraplength=300, font=self.__app.font_sm
         )
         self._lbl_version = Label(
             self._dialog, text="Version: " + VERSION, font=self.__app.font_sm
@@ -66,6 +66,13 @@ class AboutDialog:
             text="Python Version: " + python_version(),
             font=self.__app.font_sm,
         )
+        self._btn_checkupdate = Button(
+            self._dialog,
+            text="Check for update",
+            width=12,
+            font=self.__app.font_sm,
+            cursor="hand2",
+        )
         self._lbl_update = Label(
             self._dialog,
             text="",
@@ -81,6 +88,11 @@ class AboutDialog:
             text="pynmeagps Version: " + PNVERSION,
             font=self.__app.font_sm,
         )
+        self._lbl_pyrtcm_version = Label(
+            self._dialog,
+            text="pyrtcm Version: " + RTVERSION,
+            font=self.__app.font_sm,
+        )
         self._lbl_copyright = Label(
             self._dialog,
             text=COPYRIGHTTXT,
@@ -106,18 +118,21 @@ class AboutDialog:
         self._lbl_icon.grid(column=0, row=1, padx=5, pady=3)
         self._lbl_desc.grid(column=0, row=2, padx=5, pady=3)
         self._lbl_version.grid(column=0, row=3, padx=5, pady=0)
-        self._lbl_update.grid(column=0, row=4, padx=5, pady=3)
-        self._lbl_python_version.grid(column=0, row=5, padx=5, pady=0)
-        self._lbl_pynmea2_version.grid(column=0, row=6, padx=5, pady=0)
-        self._lbl_pyubx2_version.grid(column=0, row=7, padx=5, pady=0)
-        self._lbl_copyright.grid(column=0, row=8, padx=5, pady=3)
-        self._btn_ok.grid(column=0, row=9, ipadx=3, ipady=3, padx=5, pady=3)
+        self._btn_checkupdate.grid(column=0, row=4, ipadx=3, ipady=3, padx=5, pady=3)
+        self._lbl_update.grid(column=0, row=5, padx=5, pady=3)
+        self._lbl_python_version.grid(column=0, row=6, padx=5, pady=0)
+        self._lbl_pynmea2_version.grid(column=0, row=7, padx=5, pady=0)
+        self._lbl_pyubx2_version.grid(column=0, row=8, padx=5, pady=0)
+        self._lbl_pyrtcm_version.grid(column=0, row=9, padx=5, pady=0)
+        self._lbl_copyright.grid(column=0, row=10, padx=5, pady=3)
+        self._btn_ok.grid(column=0, row=11, ipadx=3, ipady=3, padx=5, pady=3)
 
     def _attach_events(self):
         """
         Bind events to dialog.
         """
 
+        self._btn_checkupdate.bind("<Button>", self._check_for_update)
         self._lbl_update.bind("<Button-1>", lambda e: open_new_tab(PYPI_URL))
         self._lbl_copyright.bind("<Button-1>", lambda e: open_new_tab(GITHUB_URL))
         self._btn_ok.bind("<Return>", self._ok_press)
@@ -131,11 +146,15 @@ class AboutDialog:
         self.__master.update_idletasks()
         self._dialog.destroy()
 
-    def _check_for_update(self):
+    def _check_for_update(self, *args, **kwargs):  # pylint: disable=unused-argument
         """
         Check for update.
         """
 
+        self._lbl_update.config(
+            text="               Checking...               ", fg="blue"
+        )
+        self.__master.update_idletasks()
         latest, ver = check_for_update("PyGPSClient")
         if latest:
             self._lbl_update.config(text="This is the latest version.", fg="green")
