@@ -35,7 +35,7 @@ BADJSONERROR = "ERROR! Invalid metadata file"
 NMEAVALERROR = "Value error in NMEA message: {}"
 SEROPENERROR = "Error opening serial port {}"
 FILEOPENERROR = "Error opening file {}"
-NOWEBMAP = "Unable to download web map."
+NOWEBMAP = "Unable to display map."
 NOWEBMAPKEY = NOWEBMAP + "\n\nMQAPIKEY not found or invalid."
 NOWEBMAPHTTP = NOWEBMAP + "\n\nBad HTTP response: {}.\nCheck MQAPIKEY."
 NOWEBMAPFIX = NOWEBMAP + "\n\nNo satellite fix."
@@ -71,6 +71,7 @@ MENUSHOWMAP = "Show Map"
 MENUHIDESATS = "Hide Satellites"
 MENUSHOWSATS = "Show Satellites"
 MENUUBXCONFIG = "UBX Configuration Dialog"
+MENUNTRIPCONFIG = "NTRIP Configuration Dialog"
 MENUHOWTO = "How To"
 MENUABOUT = "About"
 MENUHELP = "Help"
@@ -85,6 +86,8 @@ BTNRST = "Reset"
 LBLPROTDISP = "Protocols Displayed"
 LBLDATADISP = "Console Display"
 LBLUBXCONFIG = "UBX Configuration"
+LBLNTRIPCONFIG = "NTRIP Configuration"
+LBLNTRIPGGAINT = "GGA Interval"
 LBLCTL = "Controls"
 LBLSET = "Settings"
 LBLCFGPRT = "CFG-PRT Protocol Configuration"
@@ -96,9 +99,17 @@ LBLSTREAM = "Stream\nfrom file"
 LBLTRACKRECORD = "Record GPX Track"
 LBLLEGEND = "Show Legend"
 LBLSHOWUNUSED = "Show Unused Satellites"
+LBLNTRIPSERVER = "Server"
+LBLNTRIPPORT = "Port"
+LBLNTRIPVERSION = "Version"
+LBLNTRIPMOUNT = "Mountpoint"
+LBLNTRIPUSER = "User"
+LBLNTRIPPWD = "Password"
+LBLNTRIPSTR = "Sourcetable"
 
 # Dialog text
 DLGUBXCONFIG = "UBX Configuration"
+DLGNTRIPCONFIG = "NTRIP Client Configuration"
 DLGABOUT = "PyGPSClient"
 DLGHOWTO = "How To Use PyGPSCLient"
 DLGRESET = "Confirm Reset"
