@@ -7,7 +7,7 @@ Created on 22 Dec 2020
 :copyright: SEMU Consulting © 2020
 :license: BSD 3-Clause
 """
-# pylint: disable=invalid-name, too-many-instance-attributes, too-many-ancestors
+# pylint: disable=invalid-name
 
 from tkinter import (
     Frame,
@@ -17,7 +17,7 @@ from tkinter import (
 )
 from PIL import ImageTk, Image
 from pyubx2 import UBXMessage, POLL
-from .globals import (
+from pygpsclient.globals import (
     INFCOL,
     ICON_SEND,
     ICON_WARNING,
